@@ -1,15 +1,19 @@
 require File.expand_path('../helper', __FILE__)
 
-class BaseTest < Test::Unit::TestCase
-  def test_default
-    assert true
-  end
-
+class BaseTest < Minitest::Test
   describe 'Sinatra::Base subclasses' do
     class TestApp < Sinatra::Base
       get('/') { 'Hello World' }
     end
 
+    class TestKeywordArgumentInitializerApp < Sinatra::Base
+      def initialize(argument:)
+        @argument = argument
+      end
+
+      get('/') { "Hello World with Keyword Arguments: #{@argument}" }
+    end
+
     it 'include Rack::Utils' do
       assert TestApp.included_modules.include?(Rack::Utils)
     end
@@ -52,6 +56,16 @@ class BaseTest < Test::Unit::TestCase
       TestApp.configure { context = self }
       assert_equal self, context
     end
+
+    it "allows constructor to receive keyword arguments" do
+      app = TestKeywordArgumentInitializerApp.new(argument: "some argument")
+      request = Rack::MockRequest.new(app)
+
+      response = request.get('/')
+
+      assert response.ok?
+      assert_equal 'Hello World with Keyword Arguments: some argument', response.body
+    end
   end
 
   describe "Sinatra::Base#new" do
