@@ -12,7 +12,7 @@ class ERBTest < Minitest::Test
 
   def erb_app(&block)
     mock_app do
-      set :views, File.dirname(__FILE__) + '/views'
+      set :views, __dir__ + '/views'
       get('/', &block)
     end
     get '/'
