@@ -9,7 +9,7 @@ require 'active_support/core_ext/hash/conversions'
 class RablTest < Minitest::Test
   def rabl_app(&block)
     mock_app {
-      set :views, File.dirname(__FILE__) + '/views'
+      set :views, __dir__ + '/views'
       get '/', &block
     }
     get '/'
