@@ -6,7 +6,7 @@ require 'slim'
 class SlimTest < Minitest::Test
   def slim_app(&block)
     mock_app do
-      set :views, File.dirname(__FILE__) + '/views'
+      set :views, __dir__ + '/views'
       get('/', &block)
     end
     get '/'
